CedarBackup3 — cedar-backup3 3.10.0 documentation

# CedarBackup3

Implements local and remote backups to CD or DVD media.

Cedar Backup is a software package designed to manage system backups for a pool of local and remote machines. Cedar Backup understands how to back up filesystem data as well as MySQL and PostgreSQL databases and Subversion repositories. It can also be easily extended to support other kinds of data sources.

Cedar Backup is focused around weekly backups to a single CD or DVD disc, with the expectation that the disc will be changed or overwritten at the beginning of each week. If your hardware is new enough, Cedar Backup can write multisession discs, allowing you to add incremental data to a disc on a daily basis.

Besides offering command-line utilities to manage the backup process, Cedar Backup provides a well-organized library of backup-related functionality, written in the Python programming language.

author:

  Kenneth J. Pronovici <pronovic@ieee.org>

## Submodules

- CedarBackup3.action
- CedarBackup3.actions
- CedarBackup3.cli
- CedarBackup3.config
- CedarBackup3.customize
- CedarBackup3.extend
- CedarBackup3.filesystem
- CedarBackup3.image
- CedarBackup3.knapsack
- CedarBackup3.peer
- CedarBackup3.release
- CedarBackup3.scripts
- CedarBackup3.testutil
- CedarBackup3.tools
- CedarBackup3.util
- CedarBackup3.writer
- CedarBackup3.writers
- CedarBackup3.xmlutil